@@ -8,7 +8,7 @@ package Devel::EndStats;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-05-12'; # DATE
 our $DIST = 'Devel-EndStats'; # DIST
-our $VERSION = '0.211'; # VERSION
+our $VERSION = '0.212'; # VERSION
 
 our %opts = (
     verbose      => 0,
@@ -91,7 +91,7 @@ sub import {
         my $st = $opts{time_hires} ? [Time::HiRes::gettimeofday()] : time();
         my $res;
         if (wantarray) { $res = [CORE::require $arg] } else { $res = CORE::require $arg }
-        my $iv = $opts{time_hires} ? Time::HiRes::tv_interval($st, [Time::HiRes::gettimeofday()]) : time()-$st;
+        my $iv = $opts{time_hires} ? Time::HiRes::tv_interval($st) : time()-$st;
         my $memsize2 = _get_memsize() if $opts{show_memsize};
 
         # still can't make exclusive time work
@@ -113,7 +113,7 @@ sub import {
         if (wantarray) { return @$res } else { return $res }
     };
 
-    $start_time = $opts{time_hires} ? [Time::HiRes::gettimeofday] : time();
+    $start_time = $opts{time_hires} ? [Time::HiRes::gettimeofday()] : time();
 }
 
 my $begin_success;
@@ -263,7 +263,7 @@ Devel::EndStats - Display run time and dependencies after running code
 
 =head1 VERSION
 
-This document describes version 0.211 of Devel::EndStats (from Perl distribution Devel-EndStats), released on 2023-05-12.
+This document describes version 0.212 of Devel::EndStats (from Perl distribution Devel-EndStats), released on 2023-05-12.
 
 =head1 SYNOPSIS
 
